@@ -25,6 +25,15 @@ try:
 except ImportError:  # pragma: no cover.
     import csv
     clevercsv = None  # pragma: no cover.
+try:
+    import orjson
+except ImportError:  # pragma: no cover.
+    orjson = None
+try:
+    from pydantic import BaseModel as PydanticBaseModel
+except ImportError:  # pragma: no cover.
+    PydanticBaseModel = None
+
 from copy import deepcopy
 from functools import partial
 from collections.abc import Mapping
@@ -181,7 +190,7 @@ class SerializationMixin:
             '{"type_changes": {"root": {"old_type": "A", "new_type": "B", "old_value": "obj A", "new_value": "obj B"}}}'
         """
         dic = self.to_dict(view_override=TEXT_VIEW)
-        return json.dumps(dic, default=json_convertor_default(default_mapping=default_mapping), **kwargs)
+        return json_dumps(dic, default_mapping=default_mapping, **kwargs)
 
     def to_dict(self, view_override=None):
         """
@@ -302,7 +311,7 @@ class _RestrictedPickler(pickle.Pickler):
         return None
 
 
-def pickle_dump(obj, file_obj=None):
+def pickle_dump(obj, file_obj=None, protocol=4):
     """
     **pickle_dump**
     Dumps the obj into pickled content.
@@ -320,21 +329,21 @@ def pickle_dump(obj, file_obj=None):
     """
     file_obj_passed = bool(file_obj)
     file_obj = file_obj or io.BytesIO()
-    # We expect at least python 3.5 so protocol 4 is good.
-    _RestrictedPickler(file_obj, protocol=4, fix_imports=False).dump(obj)
+    _RestrictedPickler(file_obj, protocol=protocol, fix_imports=False).dump(obj)
     if not file_obj_passed:
         return file_obj.getvalue()
 
 
-def pickle_load(content, safe_to_import=None):
+def pickle_load(content=None, file_obj=None, safe_to_import=None):
     """
     **pickle_load**
     Load the pickled content. content should be a bytes object.
 
     **Parameters**
 
-    content : Bytes of pickled object. It needs to have Delta header in it that is
-        separated by a newline character from the rest of the pickled object.
+    content : Bytes of pickled object. 
+
+    file_obj : A file object to load the content from
 
     safe_to_import : A set of modules that needs to be explicitly allowed to be loaded.
         Example: {'mymodule.MyClass', 'decimal.Decimal'}
@@ -353,9 +362,13 @@ def pickle_load(content, safe_to_import=None):
 
 
     """
+    if not content and not file_obj:
+        raise ValueError('Please either pass the content or the file_obj to pickle_load.') 
     if isinstance(content, str):
         content = content.encode('utf-8')
-    return _RestrictedUnpickler(io.BytesIO(content), safe_to_import=safe_to_import).load()
+    if content:
+        file_obj = io.BytesIO(content)
+    return _RestrictedUnpickler(file_obj, safe_to_import=safe_to_import).load()
 
 
 def _get_pretty_form_text(verbose_level):
@@ -410,7 +423,7 @@ def load_path_content(path, file_type=None):
         file_type = path.split('.')[-1]
     if file_type == 'json':
         with open(path, 'r') as the_file:
-            content = json.load(the_file)
+            content = json_loads(the_file.read())
     elif file_type in {'yaml', 'yml'}:
         if yaml is None:  # pragma: no cover.
             raise ImportError('Pyyaml needs to be installed.')  # pragma: no cover.
@@ -474,7 +487,8 @@ def save_content_to_path(content, path, file_type=None, keep_backup=True):
 def _save_content(content, path, file_type, keep_backup=True):
     if file_type == 'json':
         with open(path, 'w') as the_file:
-            content = json.dump(content, the_file)
+            content = json_dumps(content)
+            the_file.write(content)
     elif file_type in {'yaml', 'yml'}:
         if yaml is None:  # pragma: no cover.
             raise ImportError('Pyyaml needs to be installed.')  # pragma: no cover.
@@ -504,8 +518,15 @@ def _save_content(content, path, file_type, keep_backup=True):
     return content
 
 
+def _serialize_decimal(value):
+    if value.as_tuple().exponent == 0:
+        return int(value)
+    else:
+        return float(value)
+
+
 JSON_CONVERTOR = {
-    decimal.Decimal: float,
+    decimal.Decimal: _serialize_decimal,
     ordered_set.OrderedSet: list,
     type: lambda x: x.__name__,
     bytes: lambda x: x.decode('utf-8'),
@@ -513,6 +534,9 @@ JSON_CONVERTOR = {
     uuid.UUID: lambda x: str(x),
 }
 
+if PydanticBaseModel:
+    JSON_CONVERTOR[PydanticBaseModel] = lambda x: x.dict()
+
 
 def json_convertor_default(default_mapping=None):
     if default_mapping:
@@ -547,12 +571,20 @@ class JSONDecoder(json.JSONDecoder):
 def json_dumps(item, default_mapping=None, **kwargs):
     """
     Dump json with extra details that are not normally json serializable
-
-    Note: I tried to replace json with orjson for its speed. It does work
-    but the output it makes is a byte object and Postgres couldn't directly use it without
-    encoding to str. So I switched back to json.
     """
-    return json.dumps(item, default=json_convertor_default(default_mapping=default_mapping), **kwargs)
+    if orjson:
+        indent = kwargs.pop('indent', None)
+        if indent:
+            kwargs['option'] = orjson.OPT_INDENT_2
+        return orjson.dumps(
+            item,
+            default=json_convertor_default(default_mapping=default_mapping),
+            **kwargs).decode(encoding='utf-8')
+    else:
+        return json.dumps(
+            item,
+            default=json_convertor_default(default_mapping=default_mapping),
+            **kwargs)
 
 
 json_loads = partial(json.loads, cls=JSONDecoder)
